{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-tools/awscli:1.0"
                },
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envName": "AWS_CONFIG_FILE",
                            "envValue": "$(inputs.aws_config.path)"
                        },
                        {
                            "envName": "AWS_SHARED_CREDENTIALS_FILE",
                            "envValue": "$(inputs.aws_shared_credentials.path)"
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#awscli_download.cwl/aws_config"
                },
                {
                    "type": "File",
                    "id": "#awscli_download.cwl/aws_shared_credentials"
                },
                {
                    "type": "string",
                    "id": "#awscli_download.cwl/s3_endpoint"
                },
                {
                    "type": "string",
                    "id": "#awscli_download.cwl/s3_profile"
                },
                {
                    "type": "string",
                    "id": "#awscli_download.cwl/s3uri"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $('aws_download.' + inputs.s3uri.split('/').slice(-1)[0] + '.time.json') aws --profile $(inputs.s3_profile) --endpoint-url $(inputs.s3_endpoint) --no-verify-ssl s3 cp $(inputs.s3uri) ."
                }
            ],
            "id": "#awscli_download.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.s3uri.split('/').slice(-1)[0])"
                    },
                    "id": "#awscli_download.cwl/output"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('aws_download.' + inputs.s3uri.split('/').slice(-1)[0] + '.time.json')"
                    },
                    "id": "#awscli_download.cwl/time_metrics"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-tools/alpine:1.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#file_check.cwl/file"
                },
                {
                    "type": "string",
                    "id": "#file_check.cwl/md5sum"
                }
            ],
            "stdout": "file_md5",
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "file_md5",
                        "loadContents": true,
                        "outputEval": "${\n  var local_md5 = self[0].contents.trim().split(' ')[0]\n  if (inputs.md5sum != local_md5){\n    return null\n  } else {\n    return inputs.file\n  }\n}\n"
                    },
                    "id": "#file_check.cwl/output"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "md5sum $(inputs.file.path)"
                }
            ],
            "id": "#file_check.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/aws_config"
                },
                {
                    "type": "File",
                    "id": "#main/aws_shared_credentials"
                },
                {
                    "type": "string",
                    "id": "#main/md5"
                },
                {
                    "type": "string",
                    "id": "#main/s3_endpoint"
                },
                {
                    "type": "string",
                    "id": "#main/s3_profile"
                },
                {
                    "type": "string",
                    "id": "#main/s3uri"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/download/time_metrics",
                    "id": "#main/time_metrics_from_download"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/checkmd5sum/output",
                    "id": "#main/verified_file"
                }
            ],
            "steps": [
                {
                    "run": "#file_check.cwl",
                    "in": [
                        {
                            "source": "#main/download/output",
                            "id": "#main/checkmd5sum/file"
                        },
                        {
                            "source": "#main/md5",
                            "id": "#main/checkmd5sum/md5sum"
                        }
                    ],
                    "out": [
                        "#main/checkmd5sum/output"
                    ],
                    "id": "#main/checkmd5sum"
                },
                {
                    "run": "#awscli_download.cwl",
                    "in": [
                        {
                            "source": "#main/aws_config",
                            "id": "#main/download/aws_config"
                        },
                        {
                            "source": "#main/aws_shared_credentials",
                            "id": "#main/download/aws_shared_credentials"
                        },
                        {
                            "source": "#main/s3_endpoint",
                            "id": "#main/download/s3_endpoint"
                        },
                        {
                            "source": "#main/s3_profile",
                            "id": "#main/download/s3_profile"
                        },
                        {
                            "source": "#main/s3uri",
                            "id": "#main/download/s3uri"
                        }
                    ],
                    "out": [
                        "#main/download/output",
                        "#main/download/time_metrics"
                    ],
                    "id": "#main/download"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
